@@ -38,6 +38,8 @@ SOURCE_REFERENCE_ID_TAG: str = 'source_reference_id'
 SOURCE_SYSTEM_TAG: str = 'source_system'
 OBJECT_PROPERTIES_TAG: str = 'relations'
 OWNER_TAG: str = 'owner'
+OWNER_ID_TAG: str = 'ownerId'
+GROUP_IDS: str = 'groupIds'
 LOCALIZED_CONTENT_TAG: str = 'LocalizedContent'
 STATUS_FLAG_TAG: str = 'status'
 CONTENT_TAG: str = 'value'
